"""movies = ["The Holy Grail", 1975, "Terry Jones & Terry Gilliam", 91,
           ["Graham Chapman", ["Michael Palin", "John Cleese", 
                                  "Terry Gilliam", "Eric Idel", "Terry Jones"]]]
"""

def print_movies(the_list):
	for each_item in the_list:
		if isinstance(each_item, list):
			print_movies(each_item)
		else:
			print(each_item)
			
#print_movies(movies)



from distutils.core import setup

setup(
        name  = 'Mnester',
        version = '1.0.0',
        py_modules = ['Mnester'],
        author = 'Wang',
        author_email = '1973919240@qq.com',
        url = 'http://www.headfirstlabs.com',
        description = 'A simple printer of nester lists',        
        )
